@@ -581,7 +581,7 @@ class EPHandler( Handler ):
 		# prevents that segment from being added to the outgoing search
 		# summary.
 		cur_seg = None
-		if self.current_segment is not None and float(self.current_segment[0]) > analysis_segment[1]:
+		if self.current_segment is not None and float(self.current_segment[0]) <= analysis_segment[1]:
 			# add the current segment
 			cur_seg = segment( self.current_segment[0], LIGOTimeGPS(analysis_segment[1]) )
 			self.seglist["state"].append( cur_seg )
@@ -716,16 +716,21 @@ class EPHandler( Handler ):
 
 		print >>sys.stderr, "Please wait (don't ctrl+c) while I dump triggers to disk."
 
-		subdir = ""
+		subdir = "./"
 		if self.outdirfmt is not None:
 			subdir = ep.append_formatted_output_path( self.outdirfmt, self )
+			subdir = self.outdir + "/" + subdir
+		if not os.path.exists( subdir ):
+			self.lock.acquire()
+			os.makedirs( subdir )
+			self.lock.release()
 		outfile = ep.make_cache_parseable_name(
 			inst = self.inst,	
 			tag = self.channel,
 			start = self.time_since_dump,
 			stop = self.stop,
 			ext = "xml.gz",
-			dir = self.outdir + subdir
+			dir = subdir
 		)
 		self.write_triggers( False, filename = outfile )
 
